DestiNet - Knowledge Networking Portal for Sustainable & Responsible Tourism

DestiNet
Knowledge Networking Portal for Sustainable & Responsible Tourism

- About
  - History
  - Create your free account
  - Guidance for DestiNet Users
  - Uses of DestiNet
- Who is Who
  - Governments & Administrations
  - Individuals
  - NGOs, Partnerships, Networks, Projects
  - Education, Research, Consultancy
  - Destinations
  - Businesses
  - MARKET PLACE
  - MARKET SOLUTIONS
  - ATLAS
  - DestiNet Users
  - ECOTRANS
- Topics
  - Natural and Cultural Heritage
  - Climate Change - Energy and Resource Efficiency
  - Destination Management and Good Governance
  - Transport and Mobility
  - Sustainable Supply Chain Management
  - Knowledge Networking, Training and Education
  - Quality Assessment, Certification and Marketing
  - Sustainable Consumption and Production & Tourism
- Resources
  - documents and publications
  - useful link for documents and information
  - Competence Training for Sustainable & Responsible Tourism Certification
  - for Businesses
  - for Destinations
  - for NGOs, Partnerships, Networks
  - for Governments & Administrations
  - for Education, Research, Consultancy
  - for Travellers
  - DEVELOPMENT SECTION
- Good Practice
  - Good Practice Examples: Destinations (Selection)
- Market Place
  - CERTIFICATES & AWARDS
  - CERTIFIED TOURISM (certifiers section)
  - Transport & Mobility Services
  - Accommodation Providers
  - Green Destinations
  - Restaurants & Catering Services
  - Tour operators, Travel agents, Intermediaries
  - Attractions
  - Activities
  - Travel Packages
- Observatory
  - Local Level Observatory Processes
  - Regional Level Observatory Processes
  - National level Observatory Processes
  - European Level Observatory Processes
  - Global Observatory Processes
  - Topic Centre for Observing Sustainable Tourism
- ATLAS
- Google Site Search

EW » Home
My DestiNet
Partnerships
ECOTRANS – DESTINET SERVICES
© Copyright ECOTRANS
2009 - 2014 All Rights Reserved. All logos and trademarks in this site are property of their respective owners.
Contact us · Disclaimer

# Log in

Tips

- » Having trouble logging in? Make sure that cookies are allowed in your browser
- » Don't forget to logout or exit your browser when you're done
- » Letting your browser to remember your username or password on this machine can be dangerous since other people might use this account to log in
- » Forgot your password? Use the password recovery form.

## Existing user

Username
Password

## New user

First create an account as a DestiNet User, and you will receive an automatic approval, to allow you to log in straightaway. Once you can log in, you can use the left hand bar options to contribute your own information to DestiNet.
Whenever you log in, your My DestiNet profile will appear. This profile gives you access to everything you upload into the portal. It will also allow you to edit your profile.